==> xlniuxdata-league-1.0.3-20150806.071324-2-sources.jar: com/xunlei/niux/data/league/dto/NiuxCashInfoDTO.java <==
package com.xunlei.niux.data.league.dto;

public class NiuxCashInfoDTO {
	private String cashNo;
	private String expireDate;
	private Double parValue;
	private String cashStatus;
	private String useTime;
	private String userId;
	private String generateNo;
	private Double minPayMoney;
	private String receiveUserId;
	private String receiveTime;
	private String receiveOrderNo;
    private String limitedgameid;
    private String description;

    public String getCashNo() {
        return cashNo;
    }

    public void setCashNo(String cashNo) {
        this.cashNo = cashNo;
    }

    public String getCashStatus() {
        return cashStatus;
    }

    public void setCashStatus(String cashStatus) {
        this.cashStatus = cashStatus;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(String expireDate) {
        this.expireDate = expireDate;
    }

    public String getGenerateNo() {
        return generateNo;
    }

    public void setGenerateNo(String generateNo) {
        this.generateNo = generateNo;
    }

    public String getLimitedgameid() {
        return limitedgameid;
    }

    public void setLimitedgameid(String limitedgameid) {
        this.limitedgameid = limitedgameid;
    }

    public Double getMinPayMoney() {
        return minPayMoney;
    }

    public void setMinPayMoney(Double minPayMoney) {
        this.minPayMoney = minPayMoney;
    }

    public Double getParValue() {
        return parValue;
    }

    public void setParValue(Double parValue) {
        this.parValue = parValue;
    }

    public String getReceiveOrderNo() {
        return receiveOrderNo;
    }

    public void setReceiveOrderNo(String receiveOrderNo) {
        this.receiveOrderNo = receiveOrderNo;
    }

    public String getReceiveTime() {
        return receiveTime;
    }

    public void setReceiveTime(String receiveTime) {
        this.receiveTime = receiveTime;
    }

    public String getReceiveUserId() {
        return receiveUserId;
    }

    public void setReceiveUserId(String receiveUserId) {
        this.receiveUserId = receiveUserId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getUseTime() {
        return useTime;
    }

    public void setUseTime(String useTime) {
        this.useTime = useTime;
    }
}

==> xlniuxdata-league-1.0.5-sources.jar: com/xunlei/niux/data/league/dto/NiuxCashInfoDTO.java <==
package com.xunlei.niux.data.league.dto;

public class NiuxCashInfoDTO {
	private String cashNo;
	private String expireDate;
	private Double parValue;
	private String cashStatus;
	private String useTime;
	private String userId;
	private String generateNo;
	private Double minPayMoney;
	private String receiveUserId;
	private String receiveTime;
	private String receiveOrderNo;
    private String limitedgameid;
    private String description;
    private Long lotGroupId;
    private String oneUserUseCashMaxTimes;

    public Long getLotGroupId() {
        return lotGroupId;
    }

    public void setLotGroupId(Long lotGroupId) {
        this.lotGroupId = lotGroupId;
    }

    public String getOneUserUseCashMaxTimes() {
        return oneUserUseCashMaxTimes;
    }

    public void setOneUserUseCashMaxTimes(String oneUserUseCashMaxTimes) {
        this.oneUserUseCashMaxTimes = oneUserUseCashMaxTimes;
    }

    public String getCashNo() {
        return cashNo;
    }

    public void setCashNo(String cashNo) {
        this.cashNo = cashNo;
    }

    public String getCashStatus() {
        return cashStatus;
    }

    public void setCashStatus(String cashStatus) {
        this.cashStatus = cashStatus;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(String expireDate) {
        this.expireDate = expireDate;
    }

    public String getGenerateNo() {
        return generateNo;
    }

    public void setGenerateNo(String generateNo) {
        this.generateNo = generateNo;
    }

    public String getLimitedgameid() {
        return limitedgameid;
    }

    public void setLimitedgameid(String limitedgameid) {
        this.limitedgameid = limitedgameid;
    }

    public Double getMinPayMoney() {
        return minPayMoney;
    }

    public void setMinPayMoney(Double minPayMoney) {
        this.minPayMoney = minPayMoney;
    }

    public Double getParValue() {
        return parValue;
    }

    public void setParValue(Double parValue) {
        this.parValue = parValue;
    }

    public String getReceiveOrderNo() {
        return receiveOrderNo;
    }

    public void setReceiveOrderNo(String receiveOrderNo) {
        this.receiveOrderNo = receiveOrderNo;
    }

    public String getReceiveTime() {
        return receiveTime;
    }

    public void setReceiveTime(String receiveTime) {
        this.receiveTime = receiveTime;
    }

    public String getReceiveUserId() {
        return receiveUserId;
    }

    public void setReceiveUserId(String receiveUserId) {
        this.receiveUserId = receiveUserId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getUseTime() {
        return useTime;
    }

    public void setUseTime(String useTime) {
        this.useTime = useTime;
    }
}
